@@ -5,12 +5,11 @@ References:
 https://github.com/mdietrichstein/tensorflow-open_nsfw
 https://github.com/yahoo/open_nsfw
 """
-
 import os
 from typing import Optional, Tuple
 
 import tensorflow as tf  # type: ignore
-from tensorflow.keras import layers  # type: ignore
+from tensorflow.keras import layers  # type: ignore # pylint: disable=import-error
 
 from ._download import get_default_weights_path, download_weights_to
 
